0001-use-pqMsg_Query-instead-of-Q.patch

application/octet-stream

Filename: 0001-use-pqMsg_Query-instead-of-Q.patch
Type: application/octet-stream
Part: 0
Message: Small patch to use pqMsg_Query instead of `Q`

Patch

Same data as JSON: GET /api/v1/attachments/:id/patch the parsed metadata as JSON — format, series position, per-file stats; never the diff bytes. API reference →
Format: format-patch
Series: patch 0001
Subject: use pqMsg_Query instead of Q Use pqMsg_Terminate in documentation instead of X
File+
src/backend/tcop/postgres.c 2 2
From 5b4e68868225b668a077116c5d02d720f180b2fe Mon Sep 17 00:00:00 2001
From: Dave Cramer <davecramer@gmail.com>
Date: Thu, 26 Dec 2024 16:04:19 -0500
Subject: [PATCH] use pqMsg_Query instead of Q Use pqMsg_Terminate in
 documentation instead of X

---
 src/backend/tcop/postgres.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/backend/tcop/postgres.c b/src/backend/tcop/postgres.c
index c01cff9d650..88694bcb302 100644
--- a/src/backend/tcop/postgres.c
+++ b/src/backend/tcop/postgres.c
@@ -310,7 +310,7 @@ InteractiveBackend(StringInfo inBuf)
 		printf("statement: %s\n", inBuf->data);
 	fflush(stdout);
 
-	return 'Q';
+	return PqMsg_Query;
 }
 
 /*
@@ -4897,7 +4897,7 @@ PostgresMain(const char *dbname, const char *username)
 				break;
 
 				/*
 				 * 'X' means that the frontend is closing down the socket. EOF
 				 * means unexpected loss of frontend connection. Either way,
 				 * perform normal shutdown.
 				 */
@@ -4897,7 +4897,7 @@ PostgresMain(const char *dbname, const char *username)
 
 				/*
-				 * 'X' means that the frontend is closing down the socket. EOF
+				 * PqMsg_Terminate('X') means that the frontend is closing down the socket. EOF
 				 * means unexpected loss of frontend connection. Either way,
 				 * perform normal shutdown.
-- 
2.39.5 (Apple Git-154)